@@ -63,7 +63,7 @@ def getHernquistProf(r, model_pars):
     r_s = model_pars['r_s']
     return rho_s/((r/r_s)*(1+r/r_s)**3)
 
-def getDensProfs(VIZ_DEST, SNAP, cat, r200s, dens_profs_fit, ROverR200_fit, dens_profs, ROverR200, obj_masses, obj_centers, method, start_time, MASS_UNIT, suffix = '_'):
+def drawDensProfs(VIZ_DEST, SNAP, r200s, dens_profs_fit, ROverR200_fit, dens_profs, ROverR200, obj_masses, obj_centers, method, nb_bins, start_time, MASS_UNIT, suffix = '_'):
     """
     Create a series of plots to analyze object shapes
     
@@ -73,9 +73,7 @@ def getDensProfs(VIZ_DEST, SNAP, cat, r200s, dens_profs_fit, ROverR200_fit, dens
     :type VIZ_DEST: string
     :param SNAP: e.g. '024'
     :type SNAP: string
-    :param cat: catalogue of objects (halos/gxs)
-    :type cat: N2-long list of lists of ints, N2 > N
-    :param r200s: catalogue of virial radii (of parent halos in case of gxs)
+    :param r200s: catalogue of virial radii (of parent halos) in Mpc/h
     :type r200s: N2-long float array
     :param dens_profs_fit: density profiles, defined at ``ROverR200``, in M_sun*h^2/(Mpc)**3
     :type dens_profs_fit: (N, r_res2) floats
@@ -86,15 +84,17 @@ def getDensProfs(VIZ_DEST, SNAP, cat, r200s, dens_profs_fit, ROverR200_fit, dens
     :type dens_profs: (N, r_res1) floats
     :param ROverR200: normalized radii at which ``dens_profs`` are defined
     :type ROverR200: (N, r_res1) floats
-    :param obj_masses: masses of objects in M_sun/h
+    :param obj_masses: masses of objects in 10^10*M_sun/h
     :type obj_masses: (N,) floats
     :param obj_centers: centers of objects, each coordinate in Mpc/h
     :type obj_centers: (N,3) floats
     :param method: string describing density profile model assumed for fitting
     :type method: string, either `einasto`, `alpha_beta_gamma`, `hernquist`, `nfw`
+    :param nb_bins: Number of mass bins to plot density profiles for
+    :type nb_bins: int
     :param start_time: time of start of shape analysis
     :type start_time: float
-    :param MASS_UNIT: conversion factor from previous mass unit to M_sun/h
+    :param MASS_UNIT: conversion factor from previous mass unit to M_sun/h, usually 10^10
     :type MASS_UNIT: float
     :param suffix: either '_dm_' or '_gx_' or '' (latter for CosmicProfsDirect)
     :type suffix: string"""
@@ -105,7 +105,8 @@ def fitDensProf(ROverR200, method, median_r200_obj_nb):
     Fit density profile according to model provided
     
     Note that ``median`` which is defined at ``ROverR200``
-    must be in units of UnitMass/(Mpc/h)**3.
+    must be in units of M_sun*h^2/(Mpc)**3. ``r200`` must be
+    in units of Mpc/h.
     
     :param ROverR200: normalized radii where ``median`` is defined and 
         fitting should be carried out
@@ -113,7 +114,7 @@ def fitDensProf(ROverR200, method, median_r200_obj_nb):
     :param method: string describing density profile model assumed for fitting
     :type method: string, either `einasto`, `alpha_beta_gamma`, `hernquist`, `nfw`
     :param median_r200_obj_nb: density profile (often a median of many profiles combined,
-        in units of UNIT_MASS/(Mpc/h)**3), virial radius (of parent halo in case of gx) 
+        in units of M_sun*h^2/(Mpc)**3), virial radius (of parent halo in units of Mpc/h) 
         and object number
     :type median_r200_obj_nb: tuple of (N,) floats, float, int
     :return best_fit, obj_nb: best-fit results, object number
@@ -124,12 +125,12 @@ def fitDensProfHelper(dens_profs, ROverR200, r200s, method):
     """ Helper function to carry out density profile fitting
     
     :param dens_profs: array containing density profiles in units 
-        of UnitMass/(Mpc/h)**3)
+        of M_sun*h^2/(Mpc)**3
     :type dens_profs: (N,r_res) floats
     :param ROverR200: normalized radii where density profile is defined
         and fitting should be carried out
     :type ROverR200: (r_res,) floats
-    :param r200s: R200 values of objects
+    :param r200s: R200 values of parent halos in units of Mpc/h
     :type r200s: (N,) floats
     :param method: string describing density profile model assumed for fitting
     :type method: string, either `einasto`, `alpha_beta_gamma`, `hernquist`, `nfw`
