@@ -1,19 +1,20 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-import numpy as np
 from mpi4py import MPI
 comm = MPI.COMM_WORLD
 rank = comm.Get_rank()
 size = comm.Get_size()
 
-def getEpsilon(idx_cat, xyz, masses, L_BOX, CENTER, angle=0.0):
+def getEpsilon(idx_cat, obj_size, xyz, masses, L_BOX, CENTER, angle=0.0):
     """ Calculate the complex ellipticity (z-projected)
     
     It is obtained from the shape tensor = centred (wrt mode) second mass moment tensor
     
-    :param idx_cat: catalogue of objects (halos/gxs)
-    :type idx_cat: list of lists of ints
+    :param idx_cat: each row contains indices of particles belonging to an object
+    :type idx_cat: (N1, N3) integers
+    :param obj_size: indicates how many particles are in each object
+    :type obj_size: (N1,) integers
     :param xyz: coordinates of particles of type 1 or type 4
     :type xyz: (N^3x3) floats
     :param masses: masses of particles of type 1 or type 4
@@ -32,13 +33,13 @@ def getEpsilon(idx_cat, xyz, masses, L_BOX, CENTER, angle=0.0):
 
 def getShape(Rs, d, param_interest, ERROR_METHOD, D_LOGSTART, D_LOGEND, D_BINS):
     """ Get average profile for param_interest (which is defined at all values of d)
-    at all elliptical radii Rs
+    at all ellipsoidal radii Rs
     
-    :param Rs: elliptical radii of interest
+    :param Rs: ellipsoidal radii of interest
     :type Rs: (N,) floats
-    :param d: param_interest is defined at all elliptical radii d
+    :param d: param_interest is defined at all ellipsoidal radii d
     :type d: (N2,) floats
-    :param param_interest: the quantity of interest defined at all elliptical radii d
+    :param param_interest: the quantity of interest defined at all ellipsoidal radii d
     :type param_interest: (N2,) floats
     :param ERROR_METHOD: mean (if ERROR_METHOD == "bootstrap" or "SEM") or median
         (if ERROR_METHOD == "median_quantile") and the +- 1 sigma error attached
@@ -57,7 +58,7 @@ def getShapeMs(Rs, d, idx_groups, group, param_interest, ERROR_METHOD, D_LOGSTAR
     """ Similar to getShape, but with mass-splitting"""
     return
 
-def getShapeProfs(VIZ_DEST, SNAP, D_LOGSTART, D_LOGEND, D_BINS, start_time, obj_masses, obj_centers, d, q, s, major_full, MASS_UNIT=1e10, suffix = '_'):
+def getShapeProfs(VIZ_DEST, SNAP, D_LOGSTART, D_LOGEND, D_BINS, start_time, obj_masses, obj_centers, d, q, s, major_full, nb_bins, MASS_UNIT=1e10, suffix = '_'):
     """
     Create a series of plots to analyze object shapes
     
@@ -75,11 +76,11 @@ def getShapeProfs(VIZ_DEST, SNAP, D_LOGSTART, D_LOGEND, D_BINS, start_time, obj_
     :type D_BINS: int
     :param start_time: time of start of shape analysis
     :type start_time: float
-    :param obj_masses: total mass of objects, in internal units
+    :param obj_masses: total mass of objects, in 10^10*M_sun/h
     :type obj_masses: (N,) floats
     :param obj_centers: positions of centers of objects, in Mpc/h
     :type obj_centers: (N,3) floats
-    :param d: param_interest is defined at all elliptical radii d
+    :param d: param_interest is defined at all ellipsoidal radii d
     :type d: (N, D_BINS+1) floats
     :param q: intermediate-to-major axis ratios
     :type q: (N, D_BINS+1) floats
@@ -87,11 +88,12 @@ def getShapeProfs(VIZ_DEST, SNAP, D_LOGSTART, D_LOGEND, D_BINS, start_time, obj_
     :type s: (N, D_BINS+1) floats
     :param major_full: major axis vectors
     :type major_full: (N,D_BINS+1,3) floats
+    :param nb_bins: Number of mass bins to plot density profiles for
+    :type nb_bins: int
     :param MASS_UNIT: conversion factor from previous mass unit to M_sun/h
     :type MASS_UNIT: float
     :param suffix: either '_dm_' or '_gx_' or '' (latter for DensShapeProfs)
     :type suffix: string"""
-    
     return
 
 def getLocalTHist(VIZ_DEST, SNAP, D_LOGSTART, D_LOGEND, D_BINS, start_time, obj_masses, obj_centers, d, q, s, major_full, HIST_NB_BINS, frac_r200, MASS_UNIT, suffix = '_'):
@@ -109,7 +111,7 @@ def getLocalTHist(VIZ_DEST, SNAP, D_LOGSTART, D_LOGEND, D_BINS, start_time, obj_
     :type D_BINS: int
     :param start_time: time of start of shape analysis
     :type start_time: float
-    :param obj_masses: masses of objects, in internal units
+    :param obj_masses: masses of objects, in 10^10*M_sun/h
     :type obj_masses: (N,) floats
     :param obj_centers: centers of objects, each coordinate in Mpc/h
     :type obj_centers: (N,3) floats
@@ -131,7 +133,7 @@ def getLocalTHist(VIZ_DEST, SNAP, D_LOGSTART, D_LOGEND, D_BINS, start_time, obj_
     :type suffix: string
     """    
     return
-     
+
 def getGlobalTHist(VIZ_DEST, SNAP, start_time, obj_masses, obj_centers, d, q, s, major_full, HIST_NB_BINS, MASS_UNIT, suffix = '_'):
     """ Plot triaxiality T histogram
     
@@ -141,7 +143,7 @@ def getGlobalTHist(VIZ_DEST, SNAP, start_time, obj_masses, obj_centers, d, q, s,
     :type SNAP: string
     :param start_time: time of start of shape analysis
     :type start_time: float
-    :param obj_masses: masses of objects in M_sun/h
+    :param obj_masses: masses of objects in 10^10*M_sun/h
     :type obj_masses: (N,) floats
     :param obj_centers: centers of objects, each coordinate in Mpc/h
     :type obj_centers: (N,3) floats
@@ -160,17 +162,19 @@ def getGlobalTHist(VIZ_DEST, SNAP, start_time, obj_masses, obj_centers, d, q, s,
     :param suffix: either '_dm_' or '_gx_' or '' (latter for DensShapeProfs)
     :type suffix: string
     """    
-    return     
+    return
 
-def getGlobalEpsHist(idx_cat, xyz, masses, L_BOX, CENTER, VIZ_DEST, SNAP, suffix = '_', HIST_NB_BINS = 11):
+def getGlobalEpsHist(xyz, masses, idx_cat, obj_size, L_BOX, CENTER, VIZ_DEST, SNAP, suffix = '_', HIST_NB_BINS = 11):
     """ Plot ellipticity histogram
     
-    :param idx_cat: catalogue of objects (objs/gxs)
-    :type idx_cat: list of lists of ints
-    :param xyz: coordinates of particles of type 1 or type 4
+    :param xyz: coordinates of particles of type 1 or type 4, in Mpc/h
     :type xyz: (N^3x3) floats
-    :param masses: masses of particles of type 1 or type 4, internal units
+    :param masses: masses of particles of type 1 or type 4, in 10^10*M_sun/h
     :type masses: (N^3x1) floats
+    :param idx_cat: each row contains indices of particles belonging to an object
+    :type idx_cat: (N1, N3) integers
+    :param obj_size: indicates how many particles are in each object
+    :type obj_size: (N1,) integers
     :param L_BOX: simulation box side length
     :type L_BOX: float, units: Mpc/h
     :param CENTER: shape quantities will be calculated with respect to CENTER = 'mode' (point of highest density)
@@ -184,20 +188,21 @@ def getGlobalEpsHist(idx_cat, xyz, masses, L_BOX, CENTER, VIZ_DEST, SNAP, suffix
     :type suffix: string
     :param HIST_NB_BINS: Number of histogram bins
     :type HIST_NB_BINS: int"""
-    
     return
         
-def getLocalEpsHist(idx_cat, xyz, masses, r200, L_BOX, CENTER, VIZ_DEST, SNAP, frac_r200, suffix = '_', HIST_NB_BINS = 11):
+def getLocalEpsHist(xyz, masses, r200, idx_cat, obj_size, L_BOX, CENTER, VIZ_DEST, SNAP, frac_r200, suffix = '_', HIST_NB_BINS = 11):
     """ Plot ellipticity histogram
     
-    :param idx_cat: catalogue of objects (objs/gxs)
-    :type idx_cat: list of lists of ints
     :param xyz: coordinates of particles of type 1 or type 4, in Mpc/h
     :type xyz: (N^3x3) floats
-    :param masses: masses of particles of type 1 or type 4, internal units
+    :param masses: masses of particles of type 1 or type 4, in 10^10*M_sun/h
     :type masses: (N^3x1) floats
     :param r200: R_200 radii of the parent halos
     :type r200: (N1,) floats
+    :param idx_cat: each row contains indices of particles belonging to an object
+    :type idx_cat: (N1, N3) integers
+    :param obj_size: indicates how many particles are in each object
+    :type obj_size: (N1,) integers
     :param L_BOX: simulation box side length
     :type L_BOX: float, units: Mpc/h
     :param CENTER: shape quantities will be calculated with respect to CENTER = 'mode' (point of highest density)
@@ -213,5 +218,4 @@ def getLocalEpsHist(idx_cat, xyz, masses, r200, L_BOX, CENTER, VIZ_DEST, SNAP, f
     :type suffix: string
     :param HIST_NB_BINS: Number of histogram bins
     :type HIST_NB_BINS: int"""
-    
-    return
+    return
\ No newline at end of file
