@@ -11,13 +11,15 @@ comm = MPI.COMM_WORLD
 rank = comm.Get_rank()
 size = comm.Get_size()
 
-def getEpsilon(idx_cat, xyz, masses, L_BOX, CENTER, angle=0.0):
+def getEpsilon(idx_cat, obj_size, xyz, masses, L_BOX, CENTER, angle=0.0):
     """ Calculate the complex ellipticity (z-projected)
     
     It is obtained from the shape tensor = centred (wrt mode) second mass moment tensor
     
-    :param idx_cat: catalogue of objects (halos/gxs)
-    :type idx_cat: list of lists of ints
+    :param idx_cat: each row contains indices of particles belonging to an object
+    :type idx_cat: (N1, N3) integers
+    :param obj_size: indicates how many particles are in each object
+    :type obj_size: (N1,) integers
     :param xyz: coordinates of particles of type 1 or type 4
     :type xyz: (N^3x3) floats
     :param masses: masses of particles of type 1 or type 4
@@ -35,14 +37,14 @@ def getEpsilon(idx_cat, xyz, masses, L_BOX, CENTER, angle=0.0):
     if rank == 0:
         eps = []
         rot_matrix = R.from_rotvec(angle * np.array([0, 0, 1])).as_matrix()
-        for obj in idx_cat:
+        for p, obj in enumerate(idx_cat):
             if obj != []:
-                xyz_ = respectPBCNoRef(xyz[obj], L_BOX)
+                xyz_ = respectPBCNoRef(xyz[obj[:obj_size[p]]], L_BOX)
                 if CENTER == 'mode':
-                    center = calcMode(xyz_, masses[obj], max((max(xyz_[:,0])-min(xyz_[:,0]), max(xyz_[:,1])-min(xyz_[:,1]), max(xyz_[:,2])-min(xyz_[:,2]))))
+                    center = calcMode(xyz_, masses[obj[:obj_size[p]]], max((max(xyz_[:,0])-min(xyz_[:,0]), max(xyz_[:,1])-min(xyz_[:,1]), max(xyz_[:,2])-min(xyz_[:,2]))))
                 else:
-                    center = calcCoM(xyz_, masses[obj])
-                masses_ = masses[obj]
+                    center = calcCoM(xyz_, masses[obj[:obj_size[p]]])
+                masses_ = masses[obj[:obj_size[p]]]
                 xyz_new = np.zeros((xyz_.shape[0],3))
                 for i in range(xyz_new.shape[0]):
                     xyz_new[i] = np.dot(rot_matrix, xyz_[i]-center)
@@ -58,13 +60,13 @@ def getEpsilon(idx_cat, xyz, masses, L_BOX, CENTER, angle=0.0):
 
 def getShape(Rs, d, param_interest, ERROR_METHOD, D_LOGSTART, D_LOGEND, D_BINS):
     """ Get average profile for param_interest (which is defined at all values of d)
-    at all elliptical radii Rs
+    at all ellipsoidal radii Rs
     
-    :param Rs: elliptical radii of interest
+    :param Rs: ellipsoidal radii of interest
     :type Rs: (N,) floats
-    :param d: param_interest is defined at all elliptical radii d
+    :param d: param_interest is defined at all ellipsoidal radii d
     :type d: (N2,) floats
-    :param param_interest: the quantity of interest defined at all elliptical radii d
+    :param param_interest: the quantity of interest defined at all ellipsoidal radii d
     :type param_interest: (N2,) floats
     :param ERROR_METHOD: mean (if ERROR_METHOD == "bootstrap" or "SEM") or median
         (if ERROR_METHOD == "median_quantile") and the +- 1 sigma error attached
@@ -101,7 +103,7 @@ def getShapeMs(Rs, d, idx_groups, group, param_interest, ERROR_METHOD, D_LOGSTAR
     mean, err_low, err_high = getMeanOrMedianAndError(y, "median_quantile")
     return mean, err_low, err_high
 
-def getShapeProfs(VIZ_DEST, SNAP, D_LOGSTART, D_LOGEND, D_BINS, start_time, obj_masses, obj_centers, d, q, s, major_full, MASS_UNIT=1e10, suffix = '_'):
+def getShapeProfs(VIZ_DEST, SNAP, D_LOGSTART, D_LOGEND, D_BINS, start_time, obj_masses, obj_centers, d, q, s, major_full, nb_bins, MASS_UNIT=1e10, suffix = '_'):
     """
     Create a series of plots to analyze object shapes
     
@@ -119,11 +121,11 @@ def getShapeProfs(VIZ_DEST, SNAP, D_LOGSTART, D_LOGEND, D_BINS, start_time, obj_
     :type D_BINS: int
     :param start_time: time of start of shape analysis
     :type start_time: float
-    :param obj_masses: total mass of objects, in internal units
+    :param obj_masses: total mass of objects, in 10^10*M_sun/h
     :type obj_masses: (N,) floats
     :param obj_centers: positions of centers of objects, in Mpc/h
     :type obj_centers: (N,3) floats
-    :param d: param_interest is defined at all elliptical radii d
+    :param d: param_interest is defined at all ellipsoidal radii d
     :type d: (N, D_BINS+1) floats
     :param q: intermediate-to-major axis ratios
     :type q: (N, D_BINS+1) floats
@@ -131,18 +133,22 @@ def getShapeProfs(VIZ_DEST, SNAP, D_LOGSTART, D_LOGEND, D_BINS, start_time, obj_
     :type s: (N, D_BINS+1) floats
     :param major_full: major axis vectors
     :type major_full: (N,D_BINS+1,3) floats
+    :param nb_bins: Number of mass bins to plot density profiles for
+    :type nb_bins: int
     :param MASS_UNIT: conversion factor from previous mass unit to M_sun/h
     :type MASS_UNIT: float
     :param suffix: either '_dm_' or '_gx_' or '' (latter for DensShapeProfs)
     :type suffix: string"""
     
     if rank == 0:
-        print_status(rank, start_time, "The number of objects considered is {0}".format(d.shape[0]))
         
         # Mass splitting
-        max_min_m, obj_m_groups, obj_center_groups, idx_groups = M_split(MASS_UNIT*obj_masses, obj_centers, start_time)
+        max_min_m, obj_m_groups, obj_center_groups, idx_groups = M_split(MASS_UNIT*obj_masses, obj_centers, start_time, NB_BINS = nb_bins)
+        print_status(rank, start_time, "The number of objects considered is {0}".format(d.shape[0]))
+        print_status(rank, start_time, "The mass bins (except maybe last) have size {0}".format(len(obj_m_groups[0])))
+        print_status(rank, start_time, "The number of mass bins is {0}".format(len(obj_m_groups)))
         
-        # Maximal elliptical radii
+        # Ellipsoidal radii
         Rs = np.logspace(D_LOGSTART,D_LOGEND,D_BINS+1)
         ERROR_METHOD = "median_quantile"
         
@@ -243,7 +249,7 @@ def getLocalTHist(VIZ_DEST, SNAP, D_LOGSTART, D_LOGEND, D_BINS, start_time, obj_
     :type D_BINS: int
     :param start_time: time of start of shape analysis
     :type start_time: float
-    :param obj_masses: masses of objects, in internal units
+    :param obj_masses: masses of objects, in 10^10*M_sun/h
     :type obj_masses: (N,) floats
     :param obj_centers: centers of objects, each coordinate in Mpc/h
     :type obj_centers: (N,3) floats
@@ -288,7 +294,7 @@ def getLocalTHist(VIZ_DEST, SNAP, D_LOGSTART, D_LOGEND, D_BINS, start_time, obj_
         plt.savefig("{0}/LocalTCount{1}{2}.pdf".format(VIZ_DEST, suffix, SNAP), bbox_inches="tight")
         
         t = t[np.logical_not(np.isnan(t))]
-        print_status(rank, start_time, "The number of objects considered is {0}. In degrees: The average T value for the objects is {1} and the standard deviation (assuming T is Gaussian distributed) is {2}".format(d.shape[0], round(np.average(t),2), round(np.std(t),2)))
+        print_status(rank, start_time, "The number of objects considered is {0}. The average T value for the objects is {1} and the standard deviation (assuming T is Gaussian distributed) is {2}".format(d.shape[0], round(np.average(t),2), round(np.std(t),2)))
      
 def getGlobalTHist(VIZ_DEST, SNAP, start_time, obj_masses, obj_centers, d, q, s, major_full, HIST_NB_BINS, MASS_UNIT, suffix = '_'):
     """ Plot triaxiality T histogram
@@ -299,7 +305,7 @@ def getGlobalTHist(VIZ_DEST, SNAP, start_time, obj_masses, obj_centers, d, q, s,
     :type SNAP: string
     :param start_time: time of start of shape analysis
     :type start_time: float
-    :param obj_masses: masses of objects in M_sun/h
+    :param obj_masses: masses of objects in 10^10*M_sun/h
     :type obj_masses: (N,) floats
     :param obj_centers: centers of objects, each coordinate in Mpc/h
     :type obj_centers: (N,3) floats
@@ -340,18 +346,20 @@ def getGlobalTHist(VIZ_DEST, SNAP, start_time, obj_masses, obj_centers, d, q, s,
         plt.savefig("{0}/GlobalTCount{1}{2}.pdf".format(VIZ_DEST, suffix, SNAP), bbox_inches="tight")
         
         t = t[np.logical_not(np.isnan(t))]
-        print_status(rank, start_time, "The number of objects considered is {0}. In degrees: The average T value for the objects is {1} and the standard deviation (assuming T is Gaussian distributed) is {2}".format(d.shape[0], round(np.average(t),2), round(np.std(t),2)))
+        print_status(rank, start_time, "The number of objects considered is {0}. The average T value for the objects is {1} and the standard deviation (assuming T is Gaussian distributed) is {2}".format(d.shape[0], round(np.average(t),2), round(np.std(t),2)))
      
 
-def getGlobalEpsHist(idx_cat, xyz, masses, L_BOX, CENTER, VIZ_DEST, SNAP, suffix = '_', HIST_NB_BINS = 11):
+def getGlobalEpsHist(xyz, masses, idx_cat, obj_size, L_BOX, CENTER, VIZ_DEST, SNAP, suffix = '_', HIST_NB_BINS = 11):
     """ Plot ellipticity histogram
     
-    :param idx_cat: catalogue of objects (objs/gxs)
-    :type idx_cat: list of lists of ints
-    :param xyz: coordinates of particles of type 1 or type 4
+    :param xyz: coordinates of particles of type 1 or type 4, in Mpc/h
     :type xyz: (N^3x3) floats
-    :param masses: masses of particles of type 1 or type 4, internal units
+    :param masses: masses of particles of type 1 or type 4, in 10^10*M_sun/h
     :type masses: (N^3x1) floats
+    :param idx_cat: each row contains indices of particles belonging to an object
+    :type idx_cat: (N1, N3) integers
+    :param obj_size: indicates how many particles are in each object
+    :type obj_size: (N1,) integers
     :param L_BOX: simulation box side length
     :type L_BOX: float, units: Mpc/h
     :param CENTER: shape quantities will be calculated with respect to CENTER = 'mode' (point of highest density)
@@ -367,7 +375,7 @@ def getGlobalEpsHist(idx_cat, xyz, masses, L_BOX, CENTER, VIZ_DEST, SNAP, suffix
     :type HIST_NB_BINS: int"""
     
     if rank == 0:
-        eps = getEpsilon(idx_cat, xyz, masses, L_BOX, CENTER)
+        eps = getEpsilon(idx_cat, obj_size, xyz, masses, L_BOX, CENTER)
         plt.figure()
         n, bins, patches = plt.hist(x=abs(eps), bins = np.linspace(0, 1, HIST_NB_BINS), alpha=0.7, density=True)
         plt.xlabel(r"$\epsilon$")
@@ -376,17 +384,19 @@ def getGlobalEpsHist(idx_cat, xyz, masses, L_BOX, CENTER, VIZ_DEST, SNAP, suffix
         plt.xlim(0.0, 1.0)
         plt.savefig("{0}/EpsCount{1}{2}.pdf".format(VIZ_DEST, suffix, SNAP), bbox_inches="tight")
         
-def getLocalEpsHist(idx_cat, xyz, masses, r200, L_BOX, CENTER, VIZ_DEST, SNAP, frac_r200, suffix = '_', HIST_NB_BINS = 11):
+def getLocalEpsHist(xyz, masses, r200, idx_cat, obj_size, L_BOX, CENTER, VIZ_DEST, SNAP, frac_r200, suffix = '_', HIST_NB_BINS = 11):
     """ Plot ellipticity histogram
     
-    :param idx_cat: catalogue of objects (objs/gxs)
-    :type idx_cat: list of lists of ints
     :param xyz: coordinates of particles of type 1 or type 4, in Mpc/h
     :type xyz: (N^3x3) floats
-    :param masses: masses of particles of type 1 or type 4, internal units
+    :param masses: masses of particles of type 1 or type 4, in 10^10*M_sun/h
     :type masses: (N^3x1) floats
     :param r200: R_200 radii of the parent halos
     :type r200: (N1,) floats
+    :param idx_cat: each row contains indices of particles belonging to an object
+    :type idx_cat: (N1, N3) integers
+    :param obj_size: indicates how many particles are in each object
+    :type obj_size: (N1,) integers
     :param L_BOX: simulation box side length
     :type L_BOX: float, units: Mpc/h
     :param CENTER: shape quantities will be calculated with respect to CENTER = 'mode' (point of highest density)
@@ -405,10 +415,10 @@ def getLocalEpsHist(idx_cat, xyz, masses, r200, L_BOX, CENTER, VIZ_DEST, SNAP, f
     
     if rank == 0:
         # Update h_cat so that only particles within r200 are considered
-        idx_cat_new = getCatWithinFracR200(idx_cat, xyz, L_BOX, CENTER, r200, frac_r200)
+        idx_cat_new, obj_size_new = getCatWithinFracR200(idx_cat, obj_size, xyz, L_BOX, CENTER, r200, frac_r200)
         
         # Direct fitting result prep, needed for both D and A
-        eps = getEpsilon(idx_cat_new, xyz, masses, L_BOX, CENTER)
+        eps = getEpsilon(idx_cat_new, obj_size_new, xyz, masses, L_BOX, CENTER)
         plt.figure()
         n, bins, patches = plt.hist(x=abs(eps), bins = np.linspace(0, 1, HIST_NB_BINS), alpha=0.7, density=True)
         plt.xlabel(r"$\epsilon$")
