@@ -12,17 +12,22 @@ import sys
 import inspect
 currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
 currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
-subprocess.call(['python3', 'setup.py', 'build_ext', '--inplace'], cwd=os.path.join(currentdir, '..'))
+subprocess.call(['python3', 'setup_compile.py', 'build_ext', '--inplace'], cwd=os.path.join(currentdir, '..', '..'))
 subprocess.call(['mkdir', 'viz'], cwd=os.path.join(currentdir))
 subprocess.call(['mkdir', 'cat'], cwd=os.path.join(currentdir))
 sys.path.append(os.path.join(currentdir, '..', '..')) # Only needed if cosmic_profiles is not installed
-from cosmic_profiles import genHalo, DensProfs
+from cosmic_profiles import genHalo, DensProfs, updateInUnitSystem, updateOutUnitSystem
+from mpi4py import MPI
+comm = MPI.COMM_WORLD
+rank = comm.Get_rank()
+size = comm.Get_size()
 
 def test_densities():
-    #################################### Parameters ################################################
+    #################################### Parameters #################################################
+    updateInUnitSystem(in_unit_length_in_cm = 3.085678e24, in_unit_mass_in_g = 1.989e33, in_unit_velocity_in_cm_per_s = 1e5)
+    updateOutUnitSystem(out_unit_length_in_cm = 3.085678e24, out_unit_mass_in_g = 1.989e33, out_unit_velocity_in_cm_per_s = 1e5)
     L_BOX = np.float32(10) # Mpc/h
     SNAP = '015'
-    MASS_UNIT = 1e+10
     MIN_NUMBER_DM_PTCS = 1000
     CENTER = 'mode'
     r_over_rvir = np.logspace(-2,0,50)
@@ -30,7 +35,7 @@ def test_densities():
     nb_model_pars = {'einasto': 3, 'nfw': 2, 'hernquist': 2, 'alpha_beta_gamma': 5}
     N = 10 # Number of halos used for test
     
-    #################################### Generate N mock halos ####################################
+    #################################### Generate N mock halos ######################################
     r_s = 0.5 # Units are Mpc/h
     alpha = 0.18
     
@@ -58,24 +63,31 @@ def test_densities():
         nb_ptcs = np.hstack((nb_ptcs, halo_x.shape[0]))
     dm_xyz = np.float32(np.hstack((np.reshape(dm_x, (dm_x.shape[0],1)), np.reshape(dm_y, (dm_y.shape[0],1)), np.reshape(dm_z, (dm_z.shape[0],1)))))
     
-    ######################### Extract R_vir, halo indices and halo sizes ##########################
-    mass_array = np.ones((dm_xyz.shape[0],), dtype = np.float32)*mass_dm/MASS_UNIT # Has to be in unit mass (= 10^10 M_sun/h)
-    idx_cat = [np.arange(0+np.sum(nb_ptcs[:idx]),nb_ptc+np.sum(nb_ptcs[:idx]), dtype = np.int32).tolist() for idx, nb_ptc in enumerate(nb_ptcs)]
+    ######################### Extract R_vir, halo indices and halo sizes #############################
+    mass_array = np.ones((dm_xyz.shape[0],), dtype = np.float32)*mass_dm # In M_sun/h
+    idx_cat_in = [np.arange(0+np.sum(nb_ptcs[:idx]),nb_ptc+np.sum(nb_ptcs[:idx]), dtype = np.int32).tolist() for idx, nb_ptc in enumerate(nb_ptcs)]
     
-    ########################### Define CosmicProfilesDirect object ###################################
-    cprofiles = DensProfs(dm_xyz, mass_array, idx_cat, r_vir, SNAP, L_BOX, MIN_NUMBER_DM_PTCS, CENTER)
+    ########################### Define DensProfs object ##############################################
+    cprofiles = DensProfs(dm_xyz, mass_array, idx_cat_in, r_vir, SNAP, L_BOX, MIN_NUMBER_DM_PTCS, CENTER)
     
-    ############################## Estimate Density Profile ########################################
-    dens_profs_db = cprofiles.getDensProfsDirectBinning(r_over_rvir) # dens_profs_db is in M_sun*h^2/Mpc^3
-    dens_profs_kb = cprofiles.getDensProfsKernelBased(r_over_rvir)
-    assert dens_profs_db.shape[0] == N    
-    assert dens_profs_db.shape[1] == r_over_rvir.shape[0]
-    assert dens_profs_kb.shape[0] == N    
-    assert dens_profs_kb.shape[1] == r_over_rvir.shape[0]
+    ############################## Estimate Density Profiles #########################################
+    halos_select = [0, 5]
+    dens_profs_db = cprofiles.estDensProfs(r_over_rvir, select = halos_select, direct_binning = True) # dens_profs_db is in M_sun*h^2/Mpc^3
+    dens_profs_kb = cprofiles.estDensProfs(r_over_rvir, select = halos_select, direct_binning = False) # These estimates will be kernel-based
+    if rank == 0:
+        nb_suff_res = halos_select[1]-halos_select[0]+1
+        assert dens_profs_db.shape[0] == nb_suff_res
+        assert dens_profs_db.shape[1] == r_over_rvir.shape[0]
+        assert dens_profs_kb.shape[0] == nb_suff_res
+        assert dens_profs_kb.shape[1] == r_over_rvir.shape[0]
+    else:
+        dens_profs_db = np.zeros((nb_suff_res, r_over_rvir.shape[0]), dtype = np.float32)
+    comm.Bcast(dens_profs_db, root = 0)
     
-    ############################## Fit Density Profile #############################################
+    ############################## Fit Density Profile ###############################################
     r_over_rvir = r_over_rvir[10:] # Do not fit innermost region since not reliable in practice. Use gravitational softening scale and / or relaxation timescale to estimate inner convergence radius.
     dens_profs_db = dens_profs_db[:,10:]
-    best_fits = cprofiles.getDensProfsBestFits(dens_profs_db, r_over_rvir, method = method)
-    assert best_fits.shape[0] == N
-    assert best_fits.shape[1] == nb_model_pars[method]
+    best_fits = cprofiles.fitDensProfs(dens_profs_db, r_over_rvir, method = method, select = halos_select)
+    if rank == 0:
+        assert best_fits.shape[0] == nb_suff_res
+        assert best_fits.shape[1] == nb_model_pars[method]
\ No newline at end of file
