@@ -11,24 +11,29 @@ import sys
 import inspect
 currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
 currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
-subprocess.call(['python3', 'setup.py', 'build_ext', '--inplace'], cwd=os.path.join(currentdir, '..'))
+subprocess.call(['python3', 'setup_compile.py', 'build_ext', '--inplace'], cwd=os.path.join(currentdir, '..', '..'))
 subprocess.call(['mkdir', 'viz'], cwd=os.path.join(currentdir))
 subprocess.call(['mkdir', 'cat'], cwd=os.path.join(currentdir))
 sys.path.append(os.path.join(currentdir, '..', '..')) # Only needed if cosmic_profiles is not installed
 from cosmic_profiles import updateCachingMaxGBs
-updateCachingMaxGBs(GB = 1)
-from cosmic_profiles import genHalo, DensProfs, getEinastoProf
+updateCachingMaxGBs(gbs = 1)
+from cosmic_profiles import genHalo, DensProfs, getEinastoProf, updateInUnitSystem, updateOutUnitSystem
 import matplotlib.pyplot as plt
 import matplotlib
 matplotlib.rcParams.update({'font.size': 13})
+from mpi4py import MPI
+comm = MPI.COMM_WORLD
+rank = comm.Get_rank()
+size = comm.Get_size()
 
 def test_densities_ex_script():
     
     #################################### Parameters ############################################################
+    updateInUnitSystem(in_unit_length_in_cm = 3.085678e24, in_unit_mass_in_g = 1.989e33, in_unit_velocity_in_cm_per_s = 1e5)
+    updateOutUnitSystem(out_unit_length_in_cm = 3.085678e24, out_unit_mass_in_g = 1.989e33, out_unit_velocity_in_cm_per_s = 1e5)
     L_BOX = np.float32(10) # cMpc/h
     VIZ_DEST = "./cosmic_profiles/tests/viz"
     SNAP = '015'
-    MASS_UNIT = 1e+10
     MIN_NUMBER_DM_PTCS = 200
     CENTER = 'com'
     
@@ -55,7 +60,7 @@ def test_densities_ex_script():
     dm_xyz = np.float32(np.hstack((np.reshape(halo_x, (halo_x.shape[0],1)), np.reshape(halo_y, (halo_y.shape[0],1)), np.reshape(halo_z, (halo_z.shape[0],1)))))
     
     ######################### Extract halo indices and halo sizes ##############################################
-    mass_array = np.ones((dm_xyz.shape[0],), dtype = np.float32)*mass_dm/MASS_UNIT # Has to be in unit mass (= 10^10 M_sun/h)
+    mass_array = np.ones((dm_xyz.shape[0],), dtype = np.float32)*mass_dm # In M_sun/h
     idx_cat = [np.arange(len(halo_x), dtype = np.int32).tolist()]
     
     ########################### Define DensProfs object ########################################################
@@ -63,26 +68,38 @@ def test_densities_ex_script():
     
     ############################## Estimate Density Profile ####################################################
     # Visualize density profile: A sample output is shown above!
-    dens_profs_db = cprofiles.getDensProfsDirectBinning(r_over_rvir) # dens_profs_db is in M_sun*h^2/Mpc^3
-    dens_profs_kb = cprofiles.getDensProfsKernelBased(r_over_rvir)
-    plt.figure()
-    plt.loglog(r_over_rvir, dens_profs_db[0], 'o--', label='direct binning', markersize = 3)
-    plt.loglog(r_over_rvir, dens_profs_kb[0], 'o--', label='kernel-based', markersize = 3)
-    plt.loglog(r_over_rvir, getEinastoProf(r_over_rvir*r_vir[0], model_pars), lw = 1.0, label=r'Einasto-target: $\alpha$ = {:.2f}, $r_s$ = {:.2f} cMpc/h'.format(alpha, r_s))
-    plt.xlabel(r'r/$R_{\mathrm{vir}}$')
-    plt.ylabel(r"$\rho$ [$h^2M_{{\odot}}$ / Mpc${{}}^3$]")
-    plt.legend(fontsize="small", loc='lower left')
-    plt.savefig('{}/RhoProfObj0_{}.pdf'.format(VIZ_DEST, SNAP), bbox_inches='tight')
+    halos_select = [0, 0]
+    dens_profs_db = cprofiles.estDensProfs(r_over_rvir, select = halos_select, direct_binning = True) # dens_profs_db is in M_sun*h^2/Mpc^3
+    dens_profs_kb = cprofiles.estDensProfs(r_over_rvir, select = halos_select, direct_binning = False)
+    
+    if rank == 0:
+        dens_profs_db = dens_profs_db[0]
+        dens_profs_kb = dens_profs_kb[0]
+        plt.figure()
+        plt.loglog(r_over_rvir, dens_profs_db, 'o--', label='direct binning', markersize = 3)
+        plt.loglog(r_over_rvir, dens_profs_kb, 'o--', label='kernel-based', markersize = 3)
+        plt.loglog(r_over_rvir, getEinastoProf(r_over_rvir*r_vir[0], model_pars), lw = 1.0, label=r'Einasto-target: $\alpha$ = {:.2f}, $r_s$ = {:.2f} cMpc/h'.format(alpha, r_s))
+        plt.xlabel(r'r/$R_{\mathrm{vir}}$')
+        plt.ylabel(r"$\rho$ [$h^2M_{{\odot}}$ / Mpc${{}}^3$]")
+        plt.legend(fontsize="small", loc='lower left')
+        plt.savefig('{}/RhoProfObj0_{}.pdf'.format(VIZ_DEST, SNAP), bbox_inches='tight')
+    else:
+        dens_profs_db = np.zeros((r_over_rvir.shape[0]), dtype = np.float32)
+        dens_profs_db = np.zeros((r_over_rvir.shape[0]), dtype = np.float32)
+    comm.Bcast(dens_profs_db, root = 0)
+    comm.Bcast(dens_profs_kb, root = 0)
     
     ############################## Fit Density Profile #########################################################
     r_over_rvir_fit = r_over_rvir[10:] # Do not fit innermost region since not reliable in practice. Use gravitational softening scale and / or relaxation timescale to estimate inner convergence radius.
-    dens_profs_db_fit = dens_profs_db[0,10:]
-    best_fit = cprofiles.getDensProfsBestFits(dens_profs_db_fit.reshape((1,dens_profs_db_fit.shape[0])), r_over_rvir_fit, method = 'einasto')
-    plt.figure()
-    plt.loglog(r_over_rvir, dens_profs_db[0], 'o--', label='density profile', markersize = 4)
-    model_pars = {'rho_s': best_fit[0,0], 'alpha': best_fit[0,1], 'r_s': best_fit[0,2]}
-    plt.loglog(r_over_rvir_fit, getEinastoProf(r_over_rvir_fit*r_vir[0], model_pars), '--', color = 'r', label=r'Einasto-fit')
-    plt.xlabel(r'r/$R_{\mathrm{vir}}$')
-    plt.ylabel(r"$\rho$ [$h^2M_{{\odot}}$ / Mpc${{}}^3$]")
-    plt.legend(fontsize="small", bbox_to_anchor=(0.95, 1), loc='upper right')
-    plt.savefig('{}/RhoProfFitObj0_{}.pdf'.format(VIZ_DEST, SNAP), bbox_inches='tight')
+    dens_profs_db_fit = dens_profs_db[10:]
+    best_fit = cprofiles.fitDensProfs(dens_profs_db_fit.reshape((1,dens_profs_db_fit.shape[0])), r_over_rvir_fit, method = 'einasto', select = halos_select)
+    
+    if rank == 0:
+        plt.figure()
+        plt.loglog(r_over_rvir, dens_profs_db, 'o--', label='density profile', markersize = 4)
+        model_pars = {'rho_s': best_fit[0,0], 'alpha': best_fit[0,1], 'r_s': best_fit[0,2]}
+        plt.loglog(r_over_rvir_fit, getEinastoProf(r_over_rvir_fit*r_vir[0], model_pars), '--', color = 'r', label=r'Einasto-fit')
+        plt.xlabel(r'r/$R_{\mathrm{vir}}$')
+        plt.ylabel(r"$\rho$ [$h^2M_{{\odot}}$ / Mpc${{}}^3$]")
+        plt.legend(fontsize="small", bbox_to_anchor=(0.95, 1), loc='upper right')
+        plt.savefig('{}/RhoProfFitObj0_{}.pdf'.format(VIZ_DEST, SNAP), bbox_inches='tight')
\ No newline at end of file
