@@ -12,24 +12,29 @@ import sys
 import inspect
 currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
 currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
-subprocess.call(['python3', 'setup.py', 'build_ext', '--inplace'], cwd=os.path.join(currentdir, '..'))
+subprocess.call(['python3', 'setup_compile.py', 'build_ext', '--inplace'], cwd=os.path.join(currentdir, '..', '..'))
 subprocess.call(['mkdir', 'viz'], cwd=os.path.join(currentdir))
 subprocess.call(['mkdir', 'cat'], cwd=os.path.join(currentdir))
 sys.path.append(os.path.join(currentdir, '..', '..')) # Only needed if cosmic_profiles is not installed
-from cosmic_profiles import genHalo, DensShapeProfs
+from cosmic_profiles import genHalo, DensShapeProfs, updateInUnitSystem, updateOutUnitSystem
+from mpi4py import MPI
+comm = MPI.COMM_WORLD
+rank = comm.Get_rank()
+size = comm.Get_size()
 
 def test_shapes():
     #################################### Parameters ################################################
+    updateInUnitSystem(in_unit_length_in_cm = 3.085678e24, in_unit_mass_in_g = 1.989e33, in_unit_velocity_in_cm_per_s = 1e5)
+    updateOutUnitSystem(out_unit_length_in_cm = 3.085678e24, out_unit_mass_in_g = 1.989e33, out_unit_velocity_in_cm_per_s = 1e5)
     L_BOX = np.float32(10) # Mpc/h
     VIZ_DEST = "./cosmic_profiles/tests/viz"
     D_LOGSTART = -2
     D_LOGEND = 0
     D_BINS = 30 # If D_LOGSTART == -2 D_LOGEND == 1, 60 corresponds to shell width of 0.05 dex
-    M_TOL = np.float32(1e-2)
-    N_WALL = 100
-    N_MIN = 10
+    IT_TOL = np.float32(1e-2)
+    IT_WALL = 100
+    IT_MIN = 10
     SNAP = '015'
-    MASS_UNIT = 1e+10
     MIN_NUMBER_DM_PTCS = 1000
     CENTER = 'mode'
     HIST_NB_BINS = 11 # Number of bins used for e.g. ellipticity histogram
@@ -65,75 +70,79 @@ def test_shapes():
     dm_xyz = np.float32(np.hstack((np.reshape(dm_x, (dm_x.shape[0],1)), np.reshape(dm_y, (dm_y.shape[0],1)), np.reshape(dm_z, (dm_z.shape[0],1)))))
     
     ######################### Extract R_vir, halo indices and halo sizes ##########################
-    mass_array = np.ones((dm_xyz.shape[0],), dtype = np.float32)*mass_dm/MASS_UNIT # Has to be in unit mass (= 10^10 M_sun/h)
-    idx_cat = [np.arange(0+np.sum(nb_ptcs[:idx]),nb_ptc+np.sum(nb_ptcs[:idx]), dtype = np.int32).tolist() for idx, nb_ptc in enumerate(nb_ptcs)]
+    mass_array = np.ones((dm_xyz.shape[0],), dtype = np.float32)*mass_dm # In M_sun/h
+    idx_cat_in = [np.arange(0+np.sum(nb_ptcs[:idx]),nb_ptc+np.sum(nb_ptcs[:idx]), dtype = np.int32).tolist() for idx, nb_ptc in enumerate(nb_ptcs)]
     
     ########################### Define CosmicProfilesDirect object ###################################
-    cprofiles = DensShapeProfs(dm_xyz, mass_array, idx_cat, r_vir, SNAP, L_BOX, MIN_NUMBER_DM_PTCS, D_LOGSTART, D_LOGEND, D_BINS, M_TOL, N_WALL, N_MIN, CENTER)
+    cprofiles = DensShapeProfs(dm_xyz, mass_array, idx_cat_in, r_vir, SNAP, L_BOX, MIN_NUMBER_DM_PTCS, D_LOGSTART, D_LOGEND, D_BINS, IT_TOL, IT_WALL, IT_MIN, CENTER)
     
-    assert idx_cat == cprofiles.getIdxCat()
-    centers, ms = cprofiles.getMassesCenters()
-    nb_pass = len([1 if nb_ptc > MIN_NUMBER_DM_PTCS else 0 for nb_ptc in nb_ptcs])
-    assert centers.shape == (nb_pass,3)
-    assert ms.shape == (nb_pass,)
+    idx_cat = cprofiles.getIdxCat()[0]
+    halos_select = [0, 5]
+    centers, ms = cprofiles.getMassesCenters(halos_select)
+    if rank == 0:
+        assert len(idx_cat) <= len(idx_cat_in) # Note: idx_cat only contains objects with sufficient resolution
+        assert centers.shape == (halos_select[1] - halos_select[0] + 1,3)
+        assert ms.shape == (halos_select[1] - halos_select[0] + 1,)
     
     ######################### Calculating Local Morphological Properties #############################
     # Create halo shape catalogue
-    d, q, s, minor, inter, major, obj_centers, obj_masses = cprofiles.getShapeCatLocal(reduced = False, shell_based = False)
+    d, q, s, minor, inter, major, obj_centers, obj_masses = cprofiles.getShapeCatLocal(select = halos_select, reduced = False, shell_based = False)
     
-    idx_cat_suff = cprofiles.getIdxCatSuffRes()
-    assert np.sum([1 if idx_cat_suff[obj] != [] else 0 for obj in range(len(idx_cat))]) == d.shape[0]
-    
-    assert obj_masses.shape[0] <= nb_pass
-    assert obj_centers.shape[0] <= nb_pass
-    assert d.shape[0] <= nb_pass
-    assert q.shape[0] <= nb_pass
-    assert s.shape[0] <= nb_pass
-    assert minor.shape[0] <= nb_pass
-    assert inter.shape[0] <= nb_pass
-    assert major.shape[0] <= nb_pass
-    assert d.shape[1] == D_BINS+1
-    assert q.shape[1] == D_BINS+1
-    assert s.shape[1] == D_BINS+1
-    assert minor.shape[1] == D_BINS + 1
-    assert minor.shape[2] == 3
-    assert inter.shape[1] == D_BINS + 1
-    assert inter.shape[2] == 3
-    assert major.shape[1] == D_BINS + 1
-    assert major.shape[2] == 3
+    if rank == 0:
+        nb_suff_res = halos_select[1]-halos_select[0]+1
+        assert obj_masses.shape[0] == nb_suff_res
+        assert obj_centers.shape[0] == nb_suff_res
+        assert d.shape[0] == nb_suff_res
+        assert q.shape[0] == nb_suff_res
+        assert s.shape[0] == nb_suff_res
+        assert minor.shape[0] == nb_suff_res
+        assert inter.shape[0] == nb_suff_res
+        assert major.shape[0] == nb_suff_res
+        assert d.shape[1] == D_BINS+1
+        assert q.shape[1] == D_BINS+1
+        assert s.shape[1] == D_BINS+1
+        assert minor.shape[1] == D_BINS + 1
+        assert minor.shape[2] == 3
+        assert inter.shape[1] == D_BINS + 1
+        assert inter.shape[2] == 3
+        assert major.shape[1] == D_BINS + 1
+        assert major.shape[2] == 3
     
     # Draw halo shape profiles (overall and mass-decomposed ones)
-    cprofiles.plotShapeProfs(VIZ_DEST, reduced = True, shell_based = True)
+    cprofiles.plotShapeProfs(nb_bins = 2, VIZ_DEST = VIZ_DEST, select = halos_select, reduced = True, shell_based = True)
     
     # Viz first few halos' shapes
     cprofiles.vizLocalShapes(obj_numbers = [0,1,2], VIZ_DEST = VIZ_DEST, reduced = False, shell_based = False)
     
     # Plot halo triaxiality histogram
-    cprofiles.plotLocalTHist(HIST_NB_BINS, VIZ_DEST, frac_r200, reduced = False, shell_based = False)
+    cprofiles.plotLocalTHist(HIST_NB_BINS, VIZ_DEST, frac_r200, select = halos_select, reduced = False, shell_based = False)
     
     ######################### Calculating Global Morphological Properties ############################
-    d, q, s, minor, inter, major, obj_centers, obj_masses = cprofiles.getShapeCatGlobal(reduced = False)
+    halos_select = [0, N-1]
+    d, q, s, minor, inter, major, obj_centers, obj_masses = cprofiles.getShapeCatGlobal(select = halos_select, reduced = False)
     
-    assert obj_masses.shape[0] == nb_pass
-    assert obj_centers.shape[0] == nb_pass
-    assert d.shape[0] == nb_pass
-    assert q.shape[0] == nb_pass
-    assert s.shape[0] == nb_pass
-    assert minor.shape[0] == nb_pass
-    assert inter.shape[0] == nb_pass
-    assert major.shape[0] == nb_pass
-    assert d.shape[1] == 1
-    assert q.shape[1] == 1
-    assert s.shape[1] == 1
-    assert minor.shape[1] == 1
-    assert minor.shape[2] == 3
-    assert inter.shape[1] == 1
-    assert inter.shape[2] == 3
-    assert major.shape[1] == 1
-    assert major.shape[2] == 3
+    if rank == 0:
+        nb_suff_res = halos_select[1]-halos_select[0]+1
+        assert obj_masses.shape[0] == nb_suff_res
+        assert obj_centers.shape[0] == nb_suff_res
+        assert d.shape[0] == nb_suff_res
+        assert q.shape[0] == nb_suff_res
+        assert s.shape[0] == nb_suff_res
+        assert minor.shape[0] == nb_suff_res
+        assert inter.shape[0] == nb_suff_res
+        assert major.shape[0] == nb_suff_res
+        assert d.shape[1] == 1
+        assert q.shape[1] == 1
+        assert s.shape[1] == 1
+        assert minor.shape[1] == 1
+        assert minor.shape[2] == 3
+        assert inter.shape[1] == 1
+        assert inter.shape[2] == 3
+        assert major.shape[1] == 1
+        assert major.shape[2] == 3
     
     # Plot halo ellipticity histogram
-    cprofiles.plotGlobalEpsHist(HIST_NB_BINS, VIZ_DEST)
+    cprofiles.plotGlobalEpsHist(HIST_NB_BINS, VIZ_DEST, select = halos_select)
     
     # Viz first few halos' shapes
-    cprofiles.vizGlobalShapes(obj_numbers = [0,1,2], VIZ_DEST = VIZ_DEST, reduced = False)
+    cprofiles.vizGlobalShapes(obj_numbers = [0,1,2], VIZ_DEST = VIZ_DEST, reduced = False)
\ No newline at end of file
