@@ -17,7 +17,7 @@ import inspect
 currentdir = os.path.dirname(os.path.abspath(inspect.getfile(inspect.currentframe())))
 sys.path.append(os.path.join(currentdir, '..')) # Only needed if cosmic_profiles is not installed
 import numpy as np
-from cosmic_profiles import DensShapeProfs, getMassDMParticle
+from cosmic_profiles import DensShapeProfs, getMassDMParticle, updateInUnitSystem, updateOutUnitSystem
 from nbodykit.lab import cosmology, LogNormalCatalog
 
 def createLogNormUni(L_BOX, nbar, redshift, Nmesh, UNIT_MASS):
@@ -66,6 +66,8 @@ def createLogNormUni(L_BOX, nbar, redshift, Nmesh, UNIT_MASS):
         return None, None, None, None, None, None, None, None
 
 ############## Parameters ####################################################################################
+updateInUnitSystem(in_unit_length_in_cm = 3.085678e24, in_unit_mass_in_g = 1.989e43, in_unit_velocity_in_cm_per_s = 1e5)
+updateOutUnitSystem(out_unit_length_in_cm = 3.085678e24, out_unit_mass_in_g = 1.989e33, out_unit_velocity_in_cm_per_s = 1e5)
 L_BOX = np.float32(10) # Mpc/h
 nbar = 8e+3 # If too small, e.g. 5e+3: pynbody later yields OSError: Corrupt header record. If too large, need many GBs of RAM.
 Nmesh = 256
@@ -76,9 +78,9 @@ SNAP = '025'
 D_LOGSTART = -2
 D_LOGEND = 1
 D_BINS = 30 # If D_LOGSTART == -2 D_LOGEND == 1, 60 corresponds to shell width of 0.05 dex
-M_TOL = np.float32(1e-2)
-N_WALL = 100
-N_MIN = 10
+IT_TOL = np.float32(1e-2)
+IT_WALL = 100
+IT_MIN = 10
 MIN_NUMBER_DM_PTCS = 200
 CENTER = 'mode'
 CAT_DEST = "./cat"
@@ -87,7 +89,7 @@ VIZ_DEST = "./viz"
 
 def AHFEx():
     ############## Generate mock universe #######################################################################
-    N_tot, dm_x, dm_y, dm_z, vel_x, vel_y, vel_z, mass_array = createLogNormUni(L_BOX, nbar, redshift, Nmesh, UNIT_MASS) # mass_array in 10**10 solar masses * h^-1
+    N_tot, dm_x, dm_y, dm_z, vel_x, vel_y, vel_z, mass_array = createLogNormUni(L_BOX, nbar, redshift, Nmesh, UNIT_MASS) # mass_array in UNIT_MASS * solar masses * h^-1
     #############################################################################################################
     
     
@@ -165,7 +167,7 @@ def AHFEx():
     print("The second halo has mass {} 1e12 Msol".format(halos[2]['mass'].sum().in_units('1e12 Msol')))
     print("The first 5 particles of halo 2 are located at (in kpc)", halos[2]['pos'].in_units('kpc')[:5])
     pynbody.analysis.halo.center(halos[2]) # Modify cen_size="1 kpc" argument in analysis/halo.py's center() method to cen_size="10 kpc" if resolution is too low (i.e. nbar too low)
-    im = pynbody.plot.image(halos[2].d, width = '500 kpc', cmap=plt.cm.Greys, units = 'Msol kpc^-2')
+    pynbody.plot.image(halos[2].d, width = '500 kpc', cmap=plt.cm.Greys, units = 'Msol kpc^-2')
     plt.savefig('{}/RhoHalo2.pdf'.format(VIZ_DEST))
     #############################################################################################################
     
@@ -182,14 +184,20 @@ def AHFEx():
     #############################################################################################################
     
     ############## Run cosmic_profiles: define DensShapeProfs object ############################################
-    cprofiles = DensShapeProfs(dm_xyz, mass_array, h_indices, r_vir, SNAP, L_BOX, MIN_NUMBER_DM_PTCS, D_LOGSTART, D_LOGEND, D_BINS, M_TOL, N_WALL, N_MIN, CENTER)
+    cprofiles = DensShapeProfs(dm_xyz, mass_array, h_indices, r_vir, SNAP, L_BOX, MIN_NUMBER_DM_PTCS, D_LOGSTART, D_LOGEND, D_BINS, IT_TOL, IT_WALL, IT_MIN, CENTER)
+    if rank == 0:
+        h_idx_cat_len = len(cprofiles.getIdxCat()[0])
+    else:
+        h_idx_cat_len = None
+    h_idx_cat_len = comm.bcast(h_idx_cat_len, root = 0)
+    halos_select = [0, h_idx_cat_len//2]
     
     ############## Create local halo shape catalogue ############################################################
-    cprofiles.dumpShapeCatLocal(CAT_DEST, reduced = True, shell_based = True)
+    cprofiles.dumpShapeCatLocal(CAT_DEST, select = halos_select, reduced = True, shell_based = True)
     #############################################################################################################
     
     ############## Viz first halo ###############################################################################
     cprofiles.vizLocalShapes(obj_numbers = [0], VIZ_DEST = VIZ_DEST, reduced = True, shell_based = True)
     #############################################################################################################
     
-AHFEx()
+AHFEx()
\ No newline at end of file
